@@ -203,6 +203,7 @@ class MBIODevice(object):
         self._countMsg=0
         self._countMsgErr=0
         self._stampState=0
+        self._countProbe=0
 
         self._cache=None
 
@@ -482,6 +483,7 @@ class MBIODevice(object):
 
     def reset(self):
         self._eventReset.set()
+        self._countProbe=0
 
     def halt(self):
         self._eventHalt.set()
@@ -952,6 +954,7 @@ class MBIODevice(object):
 
         # ----------------------------------------------------
         elif self._state==self.STATE_PROBE:
+            self._countProbe+=1
             data=self.probe()
             if data:
                 try:
@@ -974,11 +977,15 @@ class MBIODevice(object):
                 self.setState(self.STATE_POWERON)
                 return
 
-            self.setState(self.STATE_ERROR, 60)
+            if self._countProbe>3:
+                self.setState(self.STATE_ERROR, 60)
+            else:
+                self.setState(self.STATE_ERROR, 5)
             return
 
         # ----------------------------------------------------
         elif self._state==self.STATE_POWERON:
+            self._countProbe=0
             self.resetConditionalRegisterWriteCount()
             self.logger.debug('Calling device %s poweron()' % self.key)
             if self.poweron():
