@@ -350,9 +350,9 @@ class MBIODeviceDigimatSIO(MBIODevice):
 
         if self.config.watchdog is not None and self.config.watchdog>0:
             data=max(min(int(self.config.watchdog), 255), 0)
-            self.writeRegistersIfChanged(170, data & 0xff)
+            self.writeRegistersIfChanged(171, data & 0xff)
         else:
-            self.writeRegistersIfChanged(170, 0)
+            self.writeRegistersIfChanged(171, 0)
 
         return True
 
@@ -375,7 +375,10 @@ class MBIODeviceDigimatSIO(MBIODevice):
                 channel0=board*self.NBCHANNELDI
                 for channel in range(self.NBCHANNELDI):
                     value=self.DI[channel0+channel]
-                    value.updateValue(r[board*8+channel])
+                    state=r[board*8+channel]
+                    if value.config.invert:
+                        state=not state
+                    value.updateValue(state)
 
     def refreshDO(self):
         r=self.readCoils(0, 8*self.config.boards)
@@ -385,7 +388,10 @@ class MBIODeviceDigimatSIO(MBIODevice):
                 channel0=board*self.NBCHANNELDO
                 for channel in range(self.NBCHANNELDO):
                     value=self.DO[channel0+channel]
-                    value.updateValue(r[board*8+channel])
+                    state=r[board*8+channel]
+                    if value.config.invert:
+                        state=not state
+                    value.updateValue(state)
 
                 self.LEDR[board].updateValue(r[board*8+4])
                 self.LEDG[board].updateValue(r[board*8+5])
@@ -462,13 +468,13 @@ class MBIODeviceDigimatSIO(MBIODevice):
 
         if self.isTimeout(self._timeoutRefreshSlow):
             self._timeoutRefreshSlow=self.timeout(15)
-            for board in range(self.config.boards):
-                r=self.readInputRegisters(98, 11)
-                if r:
-                    value=self.T
-                    value.updateValue(float(r[9])/100.0)
-                    value=self.UPTIME
-                    value.updateValue((r[2]+r[3]*60+r[4]*3600+r[5]*86400)/3600.0)
+            # for board in range(self.config.boards):
+            r=self.readInputRegisters(98, 11)
+            if r:
+                value=self.T
+                value.updateValue(float(r[9])/100.0)
+                value=self.UPTIME
+                value.updateValue((r[2]+r[3]*60+r[4]*3600+r[5]*86400)/3600.0)
 
         return 1.0
 
@@ -482,7 +488,10 @@ class MBIODeviceDigimatSIO(MBIODevice):
                     continue
                 if value.isPendingSync():
                     self.signalRefresh(0.1)
-                    self.writeCoils(board*8+channel, value.toReachValue)
+                    state=value.toReachValue
+                    if value.config.invert:
+                        state=not state
+                    self.writeCoils(board*8+channel, state)
                     value.clearSync()
                     self._timeoutRefreshDO=0
 
@@ -657,10 +666,11 @@ class SIOConfigurator(object):
         try:
             url=self.url(path)
             headers={'api_token': self._token}
+            proxies = { 'http': '', 'https': '' }
             if data is None:
                 data={}
 
-            r=requests.post(url, headers=headers, json=data, verify=False, timeout=2.0)
+            r=requests.post(url, headers=headers, json=data, verify=False, timeout=2.0, proxies=proxies)
             if r and r.ok:
                 data=r.json()
                 if data and data['status']=='success':
@@ -672,10 +682,11 @@ class SIOConfigurator(object):
         try:
             url=self.url(path)
             headers={'api_token': self._token}
+            proxies = { 'http': '', 'https': '' }
             if data is None:
                 data={}
 
-            r=requests.get(url, headers=headers, params=data, verify=False, timeout=2.0)
+            r=requests.get(url, headers=headers, params=data, verify=False, timeout=2.0, proxies=proxies)
             if r and r.ok:
                 data=r.json()
                 return data
@@ -854,6 +865,16 @@ class SIOScanner(MBIONetworkScanner):
         c.disconnect()
         return hostid
 
+    def resetmbiogateway(self, host):
+        try:
+            gateway=self.getMBIO().gateway(host)
+            if gateway is not None:
+                gateway.reset()
+                return True
+        except:
+            pass
+        return False
+
     def configureHostFromGateway(self, host, gateway):
         c=self.configurator(host)
         if c.connect():
@@ -863,14 +884,26 @@ class SIOScanner(MBIONetworkScanner):
                     # self.logger.debug(c._config)
                     gw=self.getMBIO().gw
                     self.logger.warning('Reconfiguring SIO Gateway %s -> %s/%s/%s...' % (gateway.MAC, gateway.host, mask, gw))
+                    self.getMBIO().beep()
                     c.setFixedIP(gateway.host, mask, gw)
 
                     # TODO: set RS485 and other things...
 
+                    # Try to auto-upgrade firmware
+                    if self.upgrade(host):
+                        # Device reboot will be automatic
+                        self.sleep(2)
+                        self.logger.warning('Restarting SIO Gateway %s...' % (gateway.host))
+                        gateway.reset()
+                        return
+
                     if c.isUpdated():
                         self.logger.warning('Rebooting updated SIO Gateway %s...' % (gateway.MAC))
-                        self.sleep(2)
                         c.reboot()
+                        self.sleep(2)
+                        self.logger.warning('Restarting SIO Gateway %s...' % (gateway.host))
+                        # Restart mbio gateway
+                        gateway.reset()
 
     def __repr__(self):
         if self.firmware:
