@@ -358,6 +358,13 @@ class MBIO(object):
                 except:
                     self.logger.exception('task')
 
+            for item in config.children('gsheet'):
+                try:
+                    from .gsheet import MBIOTaskGSheet
+                    MBIOTaskGSheet(self, item.get('name'), xml=item)
+                except:
+                    self.logger.exception('task')
+
             notifiers=config.child('notifiers')
             if notifiers:
                 targets=notifiers.children('target')
@@ -756,6 +763,7 @@ class MBIO(object):
                 if url[0:4].lower()!='http':
                     url='https://www.digimat.ch/'+url
                 self.logger.debug('Downloading file %s from [%s]' % (fname, url))
+                # keep system proxies if any (internet)
                 with requests.get(url, stream=True, timeout=30) as r:
                     r.raise_for_status()
                     with open(fname, 'wb') as f:
