@@ -145,6 +145,10 @@ class MBIOValue(object):
     def key(self):
         return self._key
 
+    @property
+    def tag(self):
+        return self.config.iomaptag
+
     def keyparts(self, part=None):
         try:
             parts=self.key.split('_')
@@ -183,6 +187,7 @@ class MBIOValue(object):
 
     def normalizeValue(self, value):
         if value is not None:
+            # self.logger.warning(value)
             value=float(value)
             if self._min is not None:
                 value=max(self._min, value)
@@ -481,9 +486,9 @@ class MBIOValue(object):
         if age>3600:
             age='N/A'
         if self._flags:
-            return '%s(%s=%s, flags=[%s], %ss, #%d)' % (self.__class__.__name__, self.key,
-                self.valuestr(), self._flags, age, self._notifyCount)
-        return '%s(%s=%s, %ss, #%d)' % (self.__class__.__name__, self.key, self.valuestr(), age, self._notifyCount)
+            return '%s(%s=%s, flags=[%s], %ss, #%d, tag=%s)' % (self.__class__.__name__, self.key,
+                self.valuestr(), self._flags, age, self._notifyCount, self.tag)
+        return '%s(%s=%s, %ss, #%d, tag=%s)' % (self.__class__.__name__, self.key, self.valuestr(), age, self._notifyCount, self.tag)
 
     def richstr(self):
         self.updateFlags()
@@ -494,14 +499,14 @@ class MBIOValue(object):
             color='[white]'
             if self.isFlag('AE'):
                 color='[red]'
-            if self.isFlag('M*'):
+            if self.isFlag('MR*'):
                 color='[green]'
             if self.isFlag('X'):
                 color='[bright_black]'
 
-            return '%s%s[/]([bold]%s[/bold]=%s, flags=[[bold]%s[/bold]], %ss, #%d)' % (color, self.__class__.__name__, self.key,
-                self.richvaluestr(), self._flags, age, self._notifyCount)
-        return '%s([bold]%s[/bold]=%s, %ss, #%d)' % (self.__class__.__name__, self.key, self.richvaluestr(), age, self._notifyCount)
+            return '%s%s[/]([bold]%s[/bold]=%s, flags=[[bold]%s[/bold]], %ss, #%d, tag=%s)' % (color, self.__class__.__name__, self.key,
+                self.richvaluestr(), self._flags, age, self._notifyCount, self.tag)
+        return '%s([bold]%s[/bold]=%s, %ss, #%d, tag=%s)' % (self.__class__.__name__, self.key, self.richvaluestr(), age, self._notifyCount, self.tag)
 
     def refpath(self):
         path=[]
